---
permalink: /format/
---

# Controlled Vocabulary for Dublin Core format: List of Terms

**Title:** Controlled Vocabulary for Dublin Core format: List of Terms

**Namespace URI:** http://rs.tdwg.org/format/values/

**Preferred namespace abbreviation:** acformat:

**Date version issued:** 2020-10-13

**Date created:** 2020-10-13

**Part of TDWG Standard:** http://www.tdwg.org/standards/638

**This version:** http://rs.tdwg.org/ac/doc/format/2020-10-13

**Latest version:** http://rs.tdwg.org/ac/doc/format/

**Abstract:** Audubon Core borrows the Dublin Core terms `dc:format` and `dcterms:format` to provide information about the physical or electronic format of a media item. This controlled vocabulary provides values for those two terms. 

**Contributors:** Steven J Baskauf (Vanderbilt University Heard Libraries), Matthew Blissett (GBIF), Douglas Boyer (Duke University)

**Creator:** TDWG Audubon Core Maintenance Group

**Bibliographic citation:** Audubon Core Maintenance Group. 2020. Controlled Vocabulary for Dublin Core format: List of Terms. Biodiversity Information Standards (TDWG). <http://rs.tdwg.org/ac/doc/format/2020-10-13>


## 1 Introduction (informative)

This document includes terms intended to be used as a controlled value for Dublin Core terms `dc:format` and `dcterms:format`, which are borrowed by Audubon Core.

### 1.1 Status of the content of this document

Section 1 is informative (non-normative).

Section 2 is normative except as noted.

Section 3 is informative.

In Section 4, the values of the `Term IRI`, `Definition`, and `Controlled value` are normative. The value of `Usage` (if it exists for a given term) is normative.  The values of `Has broader concept` and `Has exact match` are normative. The values of `Term Name` are non-normative, although one can expect that the namespace abbreviation prefix is one commonly used for the term namespace.  `Label` and the values of all other properties are non-normative.

### 1.2 RFC 2119 key words
The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this document are to be interpreted as described in [RFC 2119](https://tools.ietf.org/html/rfc2119).

## 2 Use of Terms

### 2.1 Relationship of value types to property terms

In accordance with [the Audubon Core Term List document](http://rs.tdwg.org/ac/doc/termlist/), unabbreviated term IRIs MUST be used as values of the property `dcterms:format`. Controlled value strings SHOULD be used as values of the property `dc:format`.

### 2.2 Relationship between concepts and concept schemes

The entry for the property `dc:format` in the [Audubon Core term list document](http://rs.tdwg.org/ac/doc/termlist/#dc_format) specifies that three kinds of string values are RECOMMENDED: Internet Media Types (MIME types), special string values for physical media, or commonly used file extensions. This controlled vocabulary defines two SKOS concept schemes, a concept scheme for media types and physical media (the first two kinds of values specified for `dc:type`) and a concept scheme for file extensions (the last recommended kind of value). Because the Internet Assigned Numbers Authority (IANA) maintains a [registry of media types](https://www.iana.org/assignments/media-types/media-types.xhtml) and Audubon Core maintains a controlled list of physical media types, using values from the media types and physical media concept scheme is RECOMMENDED over the file extensions concept scheme. 

The concept scheme for media types and physical media defines a `skos:broader` relation between each specific media type or physical medium and one of the six [Top-level Media Types defined by RFC 2046](https://tools.ietf.org/html/rfc2046#page-4V) that are related to multimedia: application, audio, image, model, text, and video. This relation MAY be used by clients to infer the general category of the media item format.

The concept scheme for file extensions defines concepts for many common file extensions used for digital media files. These concepts are usually related to one of the media types and physical media by a `skos:exactMatch` relation. Metadata creators MAY use a controlled value from the file extensions concept scheme, but because of the asserted `skos:exactMatch` relation aggregators MAY substitute the equivalent value from the media types and physical media concept scheme.

### 2.3 Example workflows (non-normative)

Workflow 1: A data provider uses spreadsheets containing a column for literal values for `dc:format`. The spreadsheets are populated with file extensions that are controlled string values from the concept scheme for file extensions. The spreadsheets are provided to an aggregator whose software "looks up" the controlled string values in the concept scheme for file extensions and determines the equivalent concepts from the concept scheme for media types and physical media. The IRIs from the concept scheme for media types and physical media are used as standardized values for `dcterms:format` in the aggregator's database.

Workflow 2: A data aggregator acquires data about multimedia items that includes file names or URLs, but no format information. The aggregator extracts the file extensions from the files or URLs and uses the concept schemes to assign a `dcterms:format` IRI value from the concept scheme for media types and physical media to each item. In cases where an item has a file extension that does not correspond to one of the controlled value strings in the concept scheme for file extensions, the aggregator uses a community-maintained table of alternate file extension values to determine the appropriate format concept for the media item.

Workflow 3: A data aggregator harvests media items from an open data repository. The remote server provides the media type via a `Content-Type` header and the file extension is determined from the file name. The aggregator cross-checks the media type value against the file extension value and uses the `skos:exactMatch` relations in the SKOS concept schemes to determine whether the values are consistent. Inconsistent pairs of values are flagged for manual checking. Previously unknown file extensions are flagged for additional research and possible inclusion in the community-maintained table of alternate file extension values.

## 3 Term index


**Concept schemes**

[file extensions concept scheme](#acformat_e) |
[media types and physical media concept scheme](#acformat_m) 

**Media types and physical media concept scheme**

[3GPP](#acformat_m028) |
[AIFF](#acformat_m031) |
[AMR](#acformat_m030) |
[application](#acformat_m001) |
[ARW raw image](#acformat_m071) |
[ASF](#acformat_m041) |
[audio](#acformat_m002) |
[audio cassette](#acformat_m057) |
[audio CD](#acformat_m044) |
[audio DVD](#acformat_m047) |
[AVI](#acformat_m029) |
[Blu-ray video disc](#acformat_m052) |
[BMP](#acformat_m009) |
[CIFF raw image](#acformat_m069) |
[CR2](#acformat_m023) |
[CR3 raw image](#acformat_m070) |
[data CD](#acformat_m043) |
[data DVD](#acformat_m046) |
[DICOM](#acformat_m066) |
[digital audio tape](#acformat_m058) |
[Digital Negative](#acformat_m022) |
[extended MPEG-2 Transport Stream](#acformat_m037) |
[FLAC](#acformat_m038) |
[GIF](#acformat_m010) |
[gLTF](#acformat_m064) |
[gLTF binary](#acformat_m063) |
[image](#acformat_m003) |
[JPEG](#acformat_m008) |
[JPEG 2000](#acformat_m024) |
[Kodak Photo CD image](#acformat_m035) |
[M4V](#acformat_m027) |
[MiniDisc](#acformat_m059) |
[mixed CD (data and audio)](#acformat_m061) |
[model](#acformat_m004) |
[MP3](#acformat_m016) |
[MP4 audio](#acformat_m015) |
[MP4 video](#acformat_m012) |
[MPEG](#acformat_m013) |
[MTL](#acformat_m067) |
[Nikon NEF Raw](#acformat_m026) |
[NTSC video DVD](#acformat_m049) |
[OBJ](#acformat_m062) |
[OGG audio](#acformat_m032) |
[OGG multiplex](#acformat_m034) |
[OGG video](#acformat_m033) |
[PAL video DVD](#acformat_m048) |
[PDF](#acformat_m018) |
[photographic print](#acformat_m051) |
[photographic slide](#acformat_m050) |
[Photoshop](#acformat_m036) |
[physical artwork](#acformat_m053) |
[plain text](#acformat_m019) |
[PNG](#acformat_m007) |
[QuickTime](#acformat_m014) |
[reel-to-reel audio tape](#acformat_m056) |
[RW2 raw image](#acformat_m072) |
[STL](#acformat_m055) |
[SVG](#acformat_m042) |
[text](#acformat_m005) |
[TIFF](#acformat_m011) |
[video](#acformat_m006) |
[video CD](#acformat_m045) |
[vinyl record](#acformat_m060) |
[VRML](#acformat_m065) |
[WAVE](#acformat_m025) |
[WMA](#acformat_m039) |
[WMV](#acformat_m040) |
[Word (post-2007) document](#acformat_m021) |
[Word (pre-2003) document](#acformat_m020) |
[X3D VRML](#acformat_m017) |
[X3D XML](#acformat_m068) |
[ZVI](#acformat_m054) 

**File extensions concept scheme**

[3GPP](#acformat_e021) |
[AIFF](#acformat_e025) |
[AMR](#acformat_e024) |
[ARW raw image](#acformat_e047) |
[ASF](#acformat_e035) |
[AVI](#acformat_e023) |
[BMP](#acformat_e017) |
[Canon Raw](#acformat_e009) |
[CIFF raw image](#acformat_e045) |
[CR3 raw image](#acformat_e046) |
[DICOM](#acformat_e041) |
[Digital Negative](#acformat_e008) |
[FLAC](#acformat_e032) |
[GIF](#acformat_e016) |
[gLTF](#acformat_e039) |
[gLTF binary](#acformat_e038) |
[JPEG](#acformat_e005) |
[JPEG 2000](#acformat_e010) |
[Kodak Photo CD image](#acformat_e029) |
[M4V](#acformat_e018) |
[MP3](#acformat_e012) |
[MP4 audio](#acformat_e014) |
[MP4 video](#acformat_e015) |
[MTL](#acformat_e042) |
[MWA](#acformat_e033) |
[Nikon NEF Raw](#acformat_e013) |
[OBJ](#acformat_e037) |
[OGG audio](#acformat_e026) |
[OGG multiplex](#acformat_e028) |
[OGG video](#acformat_e027) |
[PDF](#acformat_e006) |
[Photoshop](#acformat_e031) |
[plain text](#acformat_e001) |
[PLY](#acformat_e019) |
[PNG](#acformat_e004) |
[QuickTime](#acformat_e030) |
[RW2 raw image](#acformat_e048) |
[STL](#acformat_e020) |
[SVG](#acformat_e036) |
[TIFF](#acformat_e007) |
[VRML](#acformat_e040) |
[WAVE](#acformat_e011) |
[WMV](#acformat_e034) |
[Word (post-2007) document](#acformat_e003) |
[Word (pre-2003) document](#acformat_e002) |
[X3D VRML](#acformat_e043) |
[X3D XML](#acformat_e044) |
[ZVI](#acformat_e022) 

## 4 Vocabulary
### 4.1 Concept schemes

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e"></a>Term Name  acformat:e</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e">http://rs.tdwg.org/format/values/e</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e-2020-10-13">http://rs.tdwg.org/format/values/version/e-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>file extensions concept scheme</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>concept scheme based on conventional file extensions for media types</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>http://www.w3.org/2004/02/skos/core#ConceptScheme</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m"></a>Term Name  acformat:m</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m">http://rs.tdwg.org/format/values/m</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m-2020-10-13">http://rs.tdwg.org/format/values/version/m-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>media types and physical media concept scheme</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>concept scheme for IANA media types and various physical media items</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>http://www.w3.org/2004/02/skos/core#ConceptScheme</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>


### 4.2 Media types and physical media concept scheme

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m001"></a>Term Name  acformat:m001</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m001">http://rs.tdwg.org/format/values/m001</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m001-2020-10-13">http://rs.tdwg.org/format/values/version/m001-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>application</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for application</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m002"></a>Term Name  acformat:m002</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m002">http://rs.tdwg.org/format/values/m002</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m002-2020-10-13">http://rs.tdwg.org/format/values/version/m002-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>audio</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m003"></a>Term Name  acformat:m003</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m003">http://rs.tdwg.org/format/values/m003</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m003-2020-10-13">http://rs.tdwg.org/format/values/version/m003-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m004"></a>Term Name  acformat:m004</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m004">http://rs.tdwg.org/format/values/m004</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m004-2020-10-13">http://rs.tdwg.org/format/values/version/m004-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>model</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for model</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m005"></a>Term Name  acformat:m005</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m005">http://rs.tdwg.org/format/values/m005</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m005-2020-10-13">http://rs.tdwg.org/format/values/version/m005-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>text</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for text</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>text</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m006"></a>Term Name  acformat:m006</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m006">http://rs.tdwg.org/format/values/m006</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m006-2020-10-13">http://rs.tdwg.org/format/values/version/m006-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>video</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media type for video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m007"></a>Term Name  acformat:m007</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m007">http://rs.tdwg.org/format/values/m007</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m007-2020-10-13">http://rs.tdwg.org/format/values/version/m007-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PNG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for portable network graphics images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/png</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m008"></a>Term Name  acformat:m008</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m008">http://rs.tdwg.org/format/values/m008</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m008-2020-10-13">http://rs.tdwg.org/format/values/version/m008-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>JPEG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for JPEG images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/jpeg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m009"></a>Term Name  acformat:m009</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m009">http://rs.tdwg.org/format/values/m009</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m009-2020-10-13">http://rs.tdwg.org/format/values/version/m009-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>BMP</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for bitmap images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/bmp</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m010"></a>Term Name  acformat:m010</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m010">http://rs.tdwg.org/format/values/m010</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m010-2020-10-13">http://rs.tdwg.org/format/values/version/m010-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>GIF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for GIF images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/gif</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m011"></a>Term Name  acformat:m011</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m011">http://rs.tdwg.org/format/values/m011</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m011-2020-10-13">http://rs.tdwg.org/format/values/version/m011-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>TIFF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for TIFF images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/tiff</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m012"></a>Term Name  acformat:m012</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m012">http://rs.tdwg.org/format/values/m012</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m012-2020-10-13">http://rs.tdwg.org/format/values/version/m012-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP4 video</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for MP4 videos</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/mp4</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m013"></a>Term Name  acformat:m013</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m013">http://rs.tdwg.org/format/values/m013</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m013-2020-10-13">http://rs.tdwg.org/format/values/version/m013-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MPEG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for MPEG videos</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/mpeg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m014"></a>Term Name  acformat:m014</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m014">http://rs.tdwg.org/format/values/m014</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m014-2020-10-13">http://rs.tdwg.org/format/values/version/m014-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>QuickTime</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for QuickTime videos</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/quicktime</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m015"></a>Term Name  acformat:m015</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m015">http://rs.tdwg.org/format/values/m015</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m015-2020-10-13">http://rs.tdwg.org/format/values/version/m015-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP4 audio</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for MP4 audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/mp4</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m016"></a>Term Name  acformat:m016</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m016">http://rs.tdwg.org/format/values/m016</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m016-2020-10-13">http://rs.tdwg.org/format/values/version/m016-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP3</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for MP3 audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/mpeg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m017"></a>Term Name  acformat:m017</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m017">http://rs.tdwg.org/format/values/m017</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m017-2020-10-13">http://rs.tdwg.org/format/values/version/m017-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>X3D VRML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for X3D VRML models</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/x3d-vrml</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m018"></a>Term Name  acformat:m018</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m018">http://rs.tdwg.org/format/values/m018</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m018-2020-10-13">http://rs.tdwg.org/format/values/version/m018-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PDF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for PDF documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/pdf</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m019"></a>Term Name  acformat:m019</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m019">http://rs.tdwg.org/format/values/m019</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m019-2020-10-13">http://rs.tdwg.org/format/values/version/m019-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>plain text</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for plain text</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>text/plain</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m005">acformat:m005</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m020"></a>Term Name  acformat:m020</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m020">http://rs.tdwg.org/format/values/m020</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m020-2020-10-13">http://rs.tdwg.org/format/values/version/m020-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Word (pre-2003) document</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Microsoft Word (2003 and before) documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/msword</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m021"></a>Term Name  acformat:m021</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m021">http://rs.tdwg.org/format/values/m021</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m021-2020-10-13">http://rs.tdwg.org/format/values/version/m021-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Word (post-2007) document</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Microsoft Word (2007 and after) documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/vnd.openxmlformats-officedocument.wordprocessingml.document</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m022"></a>Term Name  acformat:m022</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m022">http://rs.tdwg.org/format/values/m022</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m022-2020-10-13">http://rs.tdwg.org/format/values/version/m022-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Digital Negative</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Digital Negative images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-adobe-dng</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m023"></a>Term Name  acformat:m023</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m023">http://rs.tdwg.org/format/values/m023</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m023-2020-10-13">http://rs.tdwg.org/format/values/version/m023-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>CR2</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Canon Raw images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-canon-cr2</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m024"></a>Term Name  acformat:m024</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m024">http://rs.tdwg.org/format/values/m024</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m024-2020-10-13">http://rs.tdwg.org/format/values/version/m024-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>JPEG 2000</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for JPEG 2000 images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/jp2</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m025"></a>Term Name  acformat:m025</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m025">http://rs.tdwg.org/format/values/m025</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m025-2020-10-13">http://rs.tdwg.org/format/values/version/m025-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>WAVE</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for WAVE audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/vnd.wave</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m026"></a>Term Name  acformat:m026</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m026">http://rs.tdwg.org/format/values/m026</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m026-2020-10-13">http://rs.tdwg.org/format/values/version/m026-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Nikon NEF Raw</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Nikon NEF Raw images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-nikon-nef</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m027"></a>Term Name  acformat:m027</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m027">http://rs.tdwg.org/format/values/m027</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m027-2020-10-13">http://rs.tdwg.org/format/values/version/m027-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>M4V</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Apple M4V videos</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/x-m4v</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m028"></a>Term Name  acformat:m028</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m028">http://rs.tdwg.org/format/values/m028</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m028-2020-10-13">http://rs.tdwg.org/format/values/version/m028-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>3GPP</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for 3GPP video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>‎video/3gpp</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m029"></a>Term Name  acformat:m029</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m029">http://rs.tdwg.org/format/values/m029</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m029-2020-10-13">http://rs.tdwg.org/format/values/version/m029-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AVI</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for AVI video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/vnd.avi</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m030"></a>Term Name  acformat:m030</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m030">http://rs.tdwg.org/format/values/m030</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m030-2020-10-13">http://rs.tdwg.org/format/values/version/m030-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AMR</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Adaptive Multi-Rate audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/AMR</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m031"></a>Term Name  acformat:m031</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m031">http://rs.tdwg.org/format/values/m031</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m031-2020-10-13">http://rs.tdwg.org/format/values/version/m031-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AIFF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Audio Interchange File Format audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/x-aiff</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m032"></a>Term Name  acformat:m032</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m032">http://rs.tdwg.org/format/values/m032</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m032-2020-10-13">http://rs.tdwg.org/format/values/version/m032-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG audio</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for OGG audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/ogg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m033"></a>Term Name  acformat:m033</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m033">http://rs.tdwg.org/format/values/m033</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m033-2020-10-13">http://rs.tdwg.org/format/values/version/m033-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG video</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for OGG video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/ogg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m034"></a>Term Name  acformat:m034</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m034">http://rs.tdwg.org/format/values/m034</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m034-2020-10-13">http://rs.tdwg.org/format/values/version/m034-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG multiplex</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for OGG multiplex</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/ogg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m035"></a>Term Name  acformat:m035</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m035">http://rs.tdwg.org/format/values/m035</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m035-2020-10-13">http://rs.tdwg.org/format/values/version/m035-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Kodak Photo CD image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Kodak Photo CD image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-photo-cd</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m036"></a>Term Name  acformat:m036</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m036">http://rs.tdwg.org/format/values/m036</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m036-2020-10-13">http://rs.tdwg.org/format/values/version/m036-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Photoshop</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Photoshop images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/vnd.adobe.photoshop</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m037"></a>Term Name  acformat:m037</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m037">http://rs.tdwg.org/format/values/m037</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m037-2020-10-13">http://rs.tdwg.org/format/values/version/m037-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>extended MPEG-2 Transport Stream</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for extended MPEG-2 Transport Stream</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/vnd.dlna.mpeg-tts</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m038"></a>Term Name  acformat:m038</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m038">http://rs.tdwg.org/format/values/m038</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m038-2020-10-13">http://rs.tdwg.org/format/values/version/m038-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>FLAC</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Free Lossless Audio Codec audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/x-flac</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m039"></a>Term Name  acformat:m039</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m039">http://rs.tdwg.org/format/values/m039</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m039-2020-10-13">http://rs.tdwg.org/format/values/version/m039-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>WMA</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Windows Media Audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio/x-ms-wma</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m040"></a>Term Name  acformat:m040</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m040">http://rs.tdwg.org/format/values/m040</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m040-2020-10-13">http://rs.tdwg.org/format/values/version/m040-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>WMV</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Windows Media Video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>video/x-ms-asf</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m041"></a>Term Name  acformat:m041</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m041">http://rs.tdwg.org/format/values/m041</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m041-2020-10-13">http://rs.tdwg.org/format/values/version/m041-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ASF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Advanced Systems Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/ms-asf</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m042"></a>Term Name  acformat:m042</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m042">http://rs.tdwg.org/format/values/m042</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m042-2020-10-13">http://rs.tdwg.org/format/values/version/m042-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>SVG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for SVG images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/svg+xml</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m043"></a>Term Name  acformat:m043</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m043">http://rs.tdwg.org/format/values/m043</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m043-2020-10-13">http://rs.tdwg.org/format/values/version/m043-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>data CD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical data compact disc</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Data-CD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m044"></a>Term Name  acformat:m044</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m044">http://rs.tdwg.org/format/values/m044</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m044-2020-10-13">http://rs.tdwg.org/format/values/version/m044-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>audio CD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical audio compact disc</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Audio-CD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m045"></a>Term Name  acformat:m045</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m045">http://rs.tdwg.org/format/values/m045</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m045-2020-10-13">http://rs.tdwg.org/format/values/version/m045-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>video CD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical video compact disc</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Video-CD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m046"></a>Term Name  acformat:m046</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m046">http://rs.tdwg.org/format/values/m046</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m046-2020-10-13">http://rs.tdwg.org/format/values/version/m046-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>data DVD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical data DVD</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Data-DVD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m047"></a>Term Name  acformat:m047</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m047">http://rs.tdwg.org/format/values/m047</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m047-2020-10-13">http://rs.tdwg.org/format/values/version/m047-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>audio DVD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical audio DVD</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Audio-DVD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m048"></a>Term Name  acformat:m048</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m048">http://rs.tdwg.org/format/values/m048</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m048-2020-10-13">http://rs.tdwg.org/format/values/version/m048-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PAL video DVD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical PAL video DVD</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Video-DVD-PAL</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m049"></a>Term Name  acformat:m049</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m049">http://rs.tdwg.org/format/values/m049</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m049-2020-10-13">http://rs.tdwg.org/format/values/version/m049-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>NTSC video DVD</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical NTSC video DVD</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Video-DVD-NTSC</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m050"></a>Term Name  acformat:m050</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m050">http://rs.tdwg.org/format/values/m050</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m050-2020-10-13">http://rs.tdwg.org/format/values/version/m050-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>photographic slide</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical photographic slide</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>photographic slide</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m051"></a>Term Name  acformat:m051</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m051">http://rs.tdwg.org/format/values/m051</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m051-2020-10-13">http://rs.tdwg.org/format/values/version/m051-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>photographic print</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical photographic print</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>photographic print</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m052"></a>Term Name  acformat:m052</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m052">http://rs.tdwg.org/format/values/m052</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m052-2020-10-13">http://rs.tdwg.org/format/values/version/m052-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Blu-ray video disc</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical Blu-ray video disc</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Blu-ray</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m006">acformat:m006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m053"></a>Term Name  acformat:m053</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m053">http://rs.tdwg.org/format/values/m053</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m053-2020-10-13">http://rs.tdwg.org/format/values/version/m053-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>physical artwork</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical drawing or painting (non-photographic)</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>physical artwork</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m054"></a>Term Name  acformat:m054</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m054">http://rs.tdwg.org/format/values/m054</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m054-2020-10-13">http://rs.tdwg.org/format/values/version/m054-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ZVI</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>unofficial media subtype for Zeiss Vision Image images</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>This media subtype is in use, but there is no subtype on the official IANA list.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/zvi</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m055"></a>Term Name  acformat:m055</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m055">http://rs.tdwg.org/format/values/m055</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m055-2020-10-13">http://rs.tdwg.org/format/values/version/m055-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>STL</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for steriolithography files</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/stl</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m056"></a>Term Name  acformat:m056</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m056">http://rs.tdwg.org/format/values/m056</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m056-2020-10-13">http://rs.tdwg.org/format/values/version/m056-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>reel-to-reel audio tape</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical analogue audio tape (reel-to-reel)</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio tape</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m057"></a>Term Name  acformat:m057</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m057">http://rs.tdwg.org/format/values/m057</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m057-2020-10-13">http://rs.tdwg.org/format/values/version/m057-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>audio cassette</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical analogue audio cassette</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>audio cassette</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m058"></a>Term Name  acformat:m058</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m058">http://rs.tdwg.org/format/values/m058</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m058-2020-10-13">http://rs.tdwg.org/format/values/version/m058-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>digital audio tape</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical digital audio tape (DAT)</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>DAT</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m059"></a>Term Name  acformat:m059</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m059">http://rs.tdwg.org/format/values/m059</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m059-2020-10-13">http://rs.tdwg.org/format/values/version/m059-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MiniDisc</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical MiniDisc </td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>MiniDisc</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m060"></a>Term Name  acformat:m060</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m060">http://rs.tdwg.org/format/values/m060</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m060-2020-10-13">http://rs.tdwg.org/format/values/version/m060-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>vinyl record</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical vinyl record</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>vinyl</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m002">acformat:m002</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m061"></a>Term Name  acformat:m061</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m061">http://rs.tdwg.org/format/values/m061</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m061-2020-10-13">http://rs.tdwg.org/format/values/version/m061-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>mixed CD (data and audio)</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>physical compact disc containing both data and audio tracks</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>Mixed-CD</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m062"></a>Term Name  acformat:m062</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m062">http://rs.tdwg.org/format/values/m062</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m062-2020-10-13">http://rs.tdwg.org/format/values/version/m062-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OBJ</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for OBJ 3D models</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/obj</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m063"></a>Term Name  acformat:m063</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m063">http://rs.tdwg.org/format/values/m063</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m063-2020-10-13">http://rs.tdwg.org/format/values/version/m063-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>gLTF binary</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Binary GL Transmission Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/gltf-binary</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m064"></a>Term Name  acformat:m064</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m064">http://rs.tdwg.org/format/values/m064</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m064-2020-10-13">http://rs.tdwg.org/format/values/version/m064-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>gLTF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for GL Transmission Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/gltf+json</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m065"></a>Term Name  acformat:m065</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m065">http://rs.tdwg.org/format/values/m065</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m065-2020-10-13">http://rs.tdwg.org/format/values/version/m065-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>VRML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Virtual Reality Modeling Language</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/vrml</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m066"></a>Term Name  acformat:m066</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m066">http://rs.tdwg.org/format/values/m066</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m066-2020-10-13">http://rs.tdwg.org/format/values/version/m066-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>DICOM</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for Digital Imaging and Communications in Medicine</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>application/dicom</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m001">acformat:m001</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m067"></a>Term Name  acformat:m067</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m067">http://rs.tdwg.org/format/values/m067</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m067-2020-10-13">http://rs.tdwg.org/format/values/version/m067-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MTL</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for OBJ Material Template Library</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/mtl</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m068"></a>Term Name  acformat:m068</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m068">http://rs.tdwg.org/format/values/m068</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m068-2020-10-13">http://rs.tdwg.org/format/values/version/m068-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>X3D XML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>media subtype for X3D XML models</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>model/x3d+xml</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m004">acformat:m004</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m069"></a>Term Name  acformat:m069</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m069">http://rs.tdwg.org/format/values/m069</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m069-2020-10-13">http://rs.tdwg.org/format/values/version/m069-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>CIFF raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>unofficial media subtype for Camera Image File Format raw image</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>This media subtype is in use, but there is no subtype on the official IANA list.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-canon-crw</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m070"></a>Term Name  acformat:m070</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m070">http://rs.tdwg.org/format/values/m070</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m070-2020-10-13">http://rs.tdwg.org/format/values/version/m070-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>CR3 raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>unofficial media subtype for Canon Raw 3 image</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>This media subtype is in use, but there is no subtype on the official IANA list.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-canon-cr3</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m071"></a>Term Name  acformat:m071</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m071">http://rs.tdwg.org/format/values/m071</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m071-2020-10-13">http://rs.tdwg.org/format/values/version/m071-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ARW raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>unofficial media subtype for Sony raw image</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>This media subtype is in use, but there is no subtype on the official IANA list.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-sony-arw</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_m072"></a>Term Name  acformat:m072</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/m072">http://rs.tdwg.org/format/values/m072</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/m072-2020-10-13">http://rs.tdwg.org/format/values/version/m072-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>RW2 raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>unofficial media subtype for Panasonic raw image</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>This media subtype is in use, but there is no subtype on the official IANA list.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>image/x-panasonic-rw2</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acformat_m003">acformat:m003</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>


### 4.3 File extensions concept scheme

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e001"></a>Term Name  acformat:e001</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e001">http://rs.tdwg.org/format/values/e001</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e001-2020-10-13">http://rs.tdwg.org/format/values/version/e001-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>plain text</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for palin text</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>txt</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m019">acformat:m019</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e002"></a>Term Name  acformat:e002</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e002">http://rs.tdwg.org/format/values/e002</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e002-2020-10-13">http://rs.tdwg.org/format/values/version/e002-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Word (pre-2003) document</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Microsoft Word (2003 and before) documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>doc</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m020">acformat:m020</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e003"></a>Term Name  acformat:e003</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e003">http://rs.tdwg.org/format/values/e003</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e003-2020-10-13">http://rs.tdwg.org/format/values/version/e003-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Word (post-2007) document</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Microsoft Word (2007 and after) documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>docx</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m021">acformat:m021</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e004"></a>Term Name  acformat:e004</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e004">http://rs.tdwg.org/format/values/e004</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e004-2020-10-13">http://rs.tdwg.org/format/values/version/e004-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PNG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for portable network graphics images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>png</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m007">acformat:m007</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e005"></a>Term Name  acformat:e005</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e005">http://rs.tdwg.org/format/values/e005</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e005-2020-10-13">http://rs.tdwg.org/format/values/version/e005-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>JPEG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for JPEG images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>jpg</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m008">acformat:m008</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e006"></a>Term Name  acformat:e006</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e006">http://rs.tdwg.org/format/values/e006</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e006-2020-10-13">http://rs.tdwg.org/format/values/version/e006-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PDF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for PDF documents</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>pdf</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m018">acformat:m018</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e007"></a>Term Name  acformat:e007</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e007">http://rs.tdwg.org/format/values/e007</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e007-2020-10-13">http://rs.tdwg.org/format/values/version/e007-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>TIFF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for TIFF images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>tif</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m011">acformat:m011</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e008"></a>Term Name  acformat:e008</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e008">http://rs.tdwg.org/format/values/e008</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e008-2020-10-13">http://rs.tdwg.org/format/values/version/e008-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Digital Negative</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Digital Negative images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>dng</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m022">acformat:m022</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e009"></a>Term Name  acformat:e009</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e009">http://rs.tdwg.org/format/values/e009</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e009-2020-10-13">http://rs.tdwg.org/format/values/version/e009-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Canon Raw</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Canon Raw images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>cr2</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m023">acformat:m023</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e010"></a>Term Name  acformat:e010</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e010">http://rs.tdwg.org/format/values/e010</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e010-2020-10-13">http://rs.tdwg.org/format/values/version/e010-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>JPEG 2000</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for JPEG 2000 images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>jp2</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m024">acformat:m024</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e011"></a>Term Name  acformat:e011</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e011">http://rs.tdwg.org/format/values/e011</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e011-2020-10-13">http://rs.tdwg.org/format/values/version/e011-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>WAVE</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for WAVE audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>wav</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m025">acformat:m025</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e012"></a>Term Name  acformat:e012</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e012">http://rs.tdwg.org/format/values/e012</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e012-2020-10-13">http://rs.tdwg.org/format/values/version/e012-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP3</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>ffle extension for MP3 audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>mp3</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m016">acformat:m016</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e013"></a>Term Name  acformat:e013</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e013">http://rs.tdwg.org/format/values/e013</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e013-2020-10-13">http://rs.tdwg.org/format/values/version/e013-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Nikon NEF Raw</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Nikon NEF Raw images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>nef</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m026">acformat:m026</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e014"></a>Term Name  acformat:e014</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e014">http://rs.tdwg.org/format/values/e014</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e014-2020-10-13">http://rs.tdwg.org/format/values/version/e014-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP4 audio</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for MP4 audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>m4a</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m015">acformat:m015</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e015"></a>Term Name  acformat:e015</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e015">http://rs.tdwg.org/format/values/e015</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e015-2020-10-13">http://rs.tdwg.org/format/values/version/e015-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MP4 video</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for MP4 video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>mp4</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m012">acformat:m012</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e016"></a>Term Name  acformat:e016</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e016">http://rs.tdwg.org/format/values/e016</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e016-2020-10-13">http://rs.tdwg.org/format/values/version/e016-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>GIF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for GIF images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>gif</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m010">acformat:m010</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e017"></a>Term Name  acformat:e017</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e017">http://rs.tdwg.org/format/values/e017</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e017-2020-10-13">http://rs.tdwg.org/format/values/version/e017-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>BMP</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for bitmap images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>bmp</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m009">acformat:m009</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e018"></a>Term Name  acformat:e018</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e018">http://rs.tdwg.org/format/values/e018</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e018-2020-10-13">http://rs.tdwg.org/format/values/version/e018-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>M4V</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Apple M4V videos</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>m4v</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m027">acformat:m027</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e019"></a>Term Name  acformat:e019</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e019">http://rs.tdwg.org/format/values/e019</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e019-2020-10-13">http://rs.tdwg.org/format/values/version/e019-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>PLY</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Polygon File Format</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>The media subtype is apparently text/plain, which would not be distinguishable from other types of plain text.</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>ply</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e020"></a>Term Name  acformat:e020</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e020">http://rs.tdwg.org/format/values/e020</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e020-2020-10-13">http://rs.tdwg.org/format/values/version/e020-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>STL</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for steriolithography files</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>stl</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m055">acformat:m055</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e021"></a>Term Name  acformat:e021</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e021">http://rs.tdwg.org/format/values/e021</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e021-2020-10-13">http://rs.tdwg.org/format/values/version/e021-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>3GPP</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for 3GPP video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>3gp</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m028">acformat:m028</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e022"></a>Term Name  acformat:e022</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e022">http://rs.tdwg.org/format/values/e022</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e022-2020-10-13">http://rs.tdwg.org/format/values/version/e022-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ZVI</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Zeiss Vision Image images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>zvi</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m054">acformat:m054</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e023"></a>Term Name  acformat:e023</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e023">http://rs.tdwg.org/format/values/e023</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e023-2020-10-13">http://rs.tdwg.org/format/values/version/e023-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AVI</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for AVI video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>avi</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m029">acformat:m029</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e024"></a>Term Name  acformat:e024</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e024">http://rs.tdwg.org/format/values/e024</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e024-2020-10-13">http://rs.tdwg.org/format/values/version/e024-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AMR</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Adaptive Multi-Rate audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>amr</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m030">acformat:m030</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e025"></a>Term Name  acformat:e025</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e025">http://rs.tdwg.org/format/values/e025</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e025-2020-10-13">http://rs.tdwg.org/format/values/version/e025-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>AIFF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Audio Interchange File Format audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>aiff</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m031">acformat:m031</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e026"></a>Term Name  acformat:e026</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e026">http://rs.tdwg.org/format/values/e026</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e026-2020-10-13">http://rs.tdwg.org/format/values/version/e026-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG audio</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for OGG audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>ogg</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m032">acformat:m032</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e027"></a>Term Name  acformat:e027</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e027">http://rs.tdwg.org/format/values/e027</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e027-2020-10-13">http://rs.tdwg.org/format/values/version/e027-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG video</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for OGG video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>ogv</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m033">acformat:m033</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e028"></a>Term Name  acformat:e028</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e028">http://rs.tdwg.org/format/values/e028</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e028-2020-10-13">http://rs.tdwg.org/format/values/version/e028-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OGG multiplex</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for OGG multiplex</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>ogx</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m034">acformat:m034</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e029"></a>Term Name  acformat:e029</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e029">http://rs.tdwg.org/format/values/e029</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e029-2020-10-13">http://rs.tdwg.org/format/values/version/e029-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Kodak Photo CD image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Kodak Photo CD image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>pcd</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m035">acformat:m035</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e030"></a>Term Name  acformat:e030</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e030">http://rs.tdwg.org/format/values/e030</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e030-2020-10-13">http://rs.tdwg.org/format/values/version/e030-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>QuickTime</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Apple QuickTime video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>mov</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m014">acformat:m014</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e031"></a>Term Name  acformat:e031</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e031">http://rs.tdwg.org/format/values/e031</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e031-2020-10-13">http://rs.tdwg.org/format/values/version/e031-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>Photoshop</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Photoshop images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>psd</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m036">acformat:m036</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e032"></a>Term Name  acformat:e032</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e032">http://rs.tdwg.org/format/values/e032</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e032-2020-10-13">http://rs.tdwg.org/format/values/version/e032-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>FLAC</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Free Lossless Audio Codec audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>flac</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m038">acformat:m038</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e033"></a>Term Name  acformat:e033</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e033">http://rs.tdwg.org/format/values/e033</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e033-2020-10-13">http://rs.tdwg.org/format/values/version/e033-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MWA</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Windows Media Audio</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>wma</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m039">acformat:m039</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e034"></a>Term Name  acformat:e034</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e034">http://rs.tdwg.org/format/values/e034</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e034-2020-10-13">http://rs.tdwg.org/format/values/version/e034-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>WMV</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Windows Media Video</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>wmv</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m040">acformat:m040</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e035"></a>Term Name  acformat:e035</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e035">http://rs.tdwg.org/format/values/e035</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e035-2020-10-13">http://rs.tdwg.org/format/values/version/e035-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ASF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Advanced Systems Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>asf</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m041">acformat:m041</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e036"></a>Term Name  acformat:e036</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e036">http://rs.tdwg.org/format/values/e036</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e036-2020-10-13">http://rs.tdwg.org/format/values/version/e036-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>SVG</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for SVG images</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>svg</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m042">acformat:m042</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e037"></a>Term Name  acformat:e037</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e037">http://rs.tdwg.org/format/values/e037</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e037-2020-10-13">http://rs.tdwg.org/format/values/version/e037-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>OBJ</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for OBJ</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>obj</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m062">acformat:m062</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e038"></a>Term Name  acformat:e038</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e038">http://rs.tdwg.org/format/values/e038</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e038-2020-10-13">http://rs.tdwg.org/format/values/version/e038-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>gLTF binary</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Binary GL Transmission Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>glb</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m063">acformat:m063</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e039"></a>Term Name  acformat:e039</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e039">http://rs.tdwg.org/format/values/e039</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e039-2020-10-13">http://rs.tdwg.org/format/values/version/e039-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>gLTF</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for GL Transmission Format</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>gltf</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m064">acformat:m064</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e040"></a>Term Name  acformat:e040</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e040">http://rs.tdwg.org/format/values/e040</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e040-2020-10-13">http://rs.tdwg.org/format/values/version/e040-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>VRML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Virtual Reality Modeling Language</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>wrl</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m065">acformat:m065</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e041"></a>Term Name  acformat:e041</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e041">http://rs.tdwg.org/format/values/e041</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e041-2020-10-13">http://rs.tdwg.org/format/values/version/e041-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>DICOM</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Digital Imaging and Communications in Medicine</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>dcm</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m066">acformat:m066</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e042"></a>Term Name  acformat:e042</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e042">http://rs.tdwg.org/format/values/e042</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e042-2020-10-13">http://rs.tdwg.org/format/values/version/e042-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>MTL</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for OBJ Material Template Library</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>mtl</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m067">acformat:m067</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e043"></a>Term Name  acformat:e043</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e043">http://rs.tdwg.org/format/values/e043</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e043-2020-10-13">http://rs.tdwg.org/format/values/version/e043-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>X3D VRML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for X3D VRML models</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>x3dv</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m017">acformat:m017</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e044"></a>Term Name  acformat:e044</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e044">http://rs.tdwg.org/format/values/e044</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e044-2020-10-13">http://rs.tdwg.org/format/values/version/e044-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>X3D XML</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for X3D XML models</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>x3d</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m068">acformat:m068</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e045"></a>Term Name  acformat:e045</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e045">http://rs.tdwg.org/format/values/e045</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e045-2020-10-13">http://rs.tdwg.org/format/values/version/e045-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>CIFF raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Camera Image File Format raw image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>crw</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m069">acformat:m069</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e046"></a>Term Name  acformat:e046</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e046">http://rs.tdwg.org/format/values/e046</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e046-2020-10-13">http://rs.tdwg.org/format/values/version/e046-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>CR3 raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Canon Raw 3 image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>cr3</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m070">acformat:m070</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e047"></a>Term Name  acformat:e047</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e047">http://rs.tdwg.org/format/values/e047</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e047-2020-10-13">http://rs.tdwg.org/format/values/version/e047-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>ARW raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Sony raw image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>arw</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m071">acformat:m071</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acformat_e048"></a>Term Name  acformat:e048</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/e048">http://rs.tdwg.org/format/values/e048</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2020-10-13</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/format/values/version/e048-2020-10-13">http://rs.tdwg.org/format/values/version/e048-2020-10-13</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>RW2 raw image</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>file extension for Panasonic raw image</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>rw2</td>
		</tr>
		<tr>
			<td>Has exact match</td>
			<td><a href="#acformat_m072">acformat:m072</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
		<tr>
			<td>Executive Committee decision</td>
			<td><a href="http://rs.tdwg.org/decisions/decision-2020-10-13_29">http://rs.tdwg.org/decisions/decision-2020-10-13_29</a></td>
		</tr>
	</tbody>
</table>


